@@ -71,6 +71,24 @@ For no authentication (when using `opencode auth login`):
   :type 'alist
   :group 'agent-shell)
 
+(defcustom agent-shell-opencode-default-model-id
+  nil
+  "Default OpenCode model ID.
+
+Must be one of the model ID's displayed under \"Available models\"
+when starting a new shell."
+  :type '(choice (const nil) string)
+  :group 'agent-shell)
+
+(defcustom agent-shell-opencode-default-session-mode-id
+  nil
+  "Default OpenCode session mode ID.
+
+Must be one of the mode ID's displayed under \"Available modes\"
+when starting a new shell."
+  :type '(choice (const nil) string)
+  :group 'agent-shell)
+
 (defcustom agent-shell-opencode-command
   '("opencode" "acp")
   "Command and parameters for the OpenCode client.
@@ -108,6 +126,8 @@ Returns an agent configuration alist using `agent-shell-make-agent-config'."
    :welcome-function #'agent-shell-opencode--welcome-message
    :client-maker (lambda (buffer)
                    (agent-shell-opencode-make-client :buffer buffer))
+   :default-model-id (lambda () agent-shell-opencode-default-model-id)
+   :default-session-mode-id (lambda () agent-shell-opencode-default-session-mode-id)
    :install-instructions "See https://opencode.ai/docs for installation."))
 
 (defun agent-shell-opencode-start-agent ()
